# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/inventory/invent/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/inventory/invent/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Inventory\\Invent\\": "packages/inventory/invent/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Inventory\Invent\Providers\InventServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Invent'  => Inventory\Invent\Facades\Invent::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Inventory\\InventTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Inventory\Invent\Providers\InventServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Inventory\Invent\Providers\InventServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Inventory\Invent\Providers\InventServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/invent/{modulename}

**User**

    http://path-to-route-folder/user/invent/{modulename}

**Public**

    http://path-to-route-folder/invents


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/invent/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/invent/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/invent/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/invent/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/invent/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/invent/{modulename}/{slug}
    METHOD: GET