<?php

namespace Inventory\Invent\Policies;

use Litepie\User\Contracts\UserPolicy;
use Inventory\Invent\Models\Tax;

class TaxPolicy
{

    /**
     * Determine if the given user can view the tax.
     *
     * @param UserPolicy $user
     * @param Tax $tax
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tax $tax)
    {
        if ($user->canDo('invent.tax.view') && $user->isAdmin()) {
            return true;
        }

        return $tax->user_id == user_id() && $tax->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tax.
     *
     * @param UserPolicy $user
     * @param Tax $tax
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('invent.tax.create');
    }

    /**
     * Determine if the given user can update the given tax.
     *
     * @param UserPolicy $user
     * @param Tax $tax
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tax $tax)
    {
        if ($user->canDo('invent.tax.edit') && $user->isAdmin()) {
            return true;
        }

        return $tax->user_id == user_id() && $tax->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tax.
     *
     * @param UserPolicy $user
     * @param Tax $tax
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tax $tax)
    {
        return $tax->user_id == user_id() && $tax->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tax.
     *
     * @param UserPolicy $user
     * @param Tax $tax
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tax $tax)
    {
        if ($user->canDo('invent.tax.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tax.
     *
     * @param UserPolicy $user
     * @param Tax $tax
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tax $tax)
    {
        if ($user->canDo('invent.tax.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
