<?php

namespace Inventory\Invent\Providers;

use Illuminate\Support\ServiceProvider;

class InventServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'invent');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'invent');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerInvent();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerInvent()
    {
        $this->app->bind('invent', function($app) {
            return new Invent($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Invent', 'Lavalite\Invent\Facades\Invent');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('inventory.invent', function ($app) {
            return $this->app->make('Inventory\Invent\Invent');
        });

        // Bind Currency to repository
        $this->app->bind(
            'Inventory\Invent\Interfaces\CurrencyRepositoryInterface',
            \Inventory\Invent\Repositories\Eloquent\CurrencyRepository::class
        );        // Bind Location to repository
        $this->app->bind(
            'Inventory\Invent\Interfaces\LocationRepositoryInterface',
            \Inventory\Invent\Repositories\Eloquent\LocationRepository::class
        );        // Bind Tax to repository
        $this->app->bind(
            'Inventory\Invent\Interfaces\TaxRepositoryInterface',
            \Inventory\Invent\Repositories\Eloquent\TaxRepository::class
        );

        $this->app->register(\Inventory\Invent\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Inventory\Invent\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and invent's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'inventory.invent'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeInvent::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['inventory.invent'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('inventory/invent.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/invent')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/invent')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
