<?php

namespace Inventory\Invent\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Inventory\Invent\Models\Invent;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Inventory\Invent\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/invent/currency/*')) {
            Route::bind('currency', function ($currency) {
                $currencyrepo = $this->app->make('Inventory\Invent\Interfaces\CurrencyRepositoryInterface');
                return $currencyrepo->findorNew($currency);
            });
        }
        if (Request::is('*/invent/location/*')) {
            Route::bind('location', function ($location) {
                $locationrepo = $this->app->make('Inventory\Invent\Interfaces\LocationRepositoryInterface');
                return $locationrepo->findorNew($location);
            });
        }
        if (Request::is('*/invent/tax/*')) {
            Route::bind('tax', function ($tax) {
                $taxrepo = $this->app->make('Inventory\Invent\Interfaces\TaxRepositoryInterface');
                return $taxrepo->findorNew($tax);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
